Author: stsp
Date: Mon Aug 18 17:27:41 2014
New Revision: 1618670

URL: http://svn.apache.org/r1618670
Log:
Use svn_wc_conflict_description3_t throughout the 'svn' command line client.

* subversion/svn/cl-conflicts.c
  (svn_cl__get_human_readable_prop_conflict_description,
   svn_cl__get_human_readable_tree_conflict_description,
   append_tree_conflict_info_xml, svn_cl__append_conflict_info_xml): Use
    svn_wc_conflict_description3_t instead of svn_wc_conflict_description2_t.

* subversion/svn/cl-conflicts.h

  (svn_cl__get_human_readable_prop_conflict_description,
   svn_cl__get_human_readable_tree_conflict_description,
   svn_cl__append_conflict_info_xml): Update declarations to use
   svn_wc_conflict_description3_t.

* subversion/svn/cl.h
  (svn_cl__conflict_func_interactive): Update declaration to use
   svn_wc_conflict_description3_t.

* subversion/svn/conflict-callbacks.c
  (show_diff, show_conflicts, merge_prop_conflict, show_prop_conflict,
   edit_prop_conflict, handle_tree_conflict, handle_prop_conflict,
   handle_tree_conflict, handle_obstructed_add, conflict_func_interactive):
   Use svn_wc_conflict_description3_t instead of svn_wc_conflict_description2_t.
   In handle_prop_conflict() we can drop a workaround that was necessary with
   the old conflict descriptor.

* subversion/svn/info-cmd.c
   (print_info_xml, print_info): Use svn_wc_conflict_description3_t instead of
    svn_wc_conflict_description2_t.

* subversion/svn/status.c
   (print_status): Update caller.

Modified:
    subversion/trunk/subversion/svn/cl-conflicts.c
    subversion/trunk/subversion/svn/cl-conflicts.h
    subversion/trunk/subversion/svn/cl.h
    subversion/trunk/subversion/svn/conflict-callbacks.c
    subversion/trunk/subversion/svn/info-cmd.c
    subversion/trunk/subversion/svn/status.c

Modified: subversion/trunk/subversion/svn/cl-conflicts.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/cl-conflicts.c?rev=1618670&r1=1618669&r2=1618670&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/cl-conflicts.c (original)
+++ subversion/trunk/subversion/svn/cl-conflicts.c Mon Aug 18 17:27:41 2014
@@ -194,14 +194,14 @@ operation_str(svn_wc_operation_t operati
 svn_error_t *
 svn_cl__get_human_readable_prop_conflict_description(
   const char **desc,
-  const svn_wc_conflict_description2_t *conflict,
+  const svn_wc_conflict_description3_t *conflict,
   apr_pool_t *pool)
 {
   const char *reason_str, *action_str;
 
   /* We provide separately translatable strings for the values that we
    * know about, and a fall-back in case any other values occur. */
-  switch (conflict->reason)
+  switch (conflict->local_change)
     {
       case svn_wc_conflict_reason_edited:
         reason_str = _("local edit");
@@ -218,10 +218,10 @@ svn_cl__get_human_readable_prop_conflict
       default:
         reason_str = apr_psprintf(pool, _("local %s"),
                                   svn_token__to_word(map_conflict_reason_xml,
-                                                     conflict->reason));
+                                                     conflict->local_change));
         break;
     }
-  switch (conflict->action)
+  switch (conflict->incoming_change)
     {
       case svn_wc_conflict_action_edit:
         action_str = _("incoming edit");
@@ -234,8 +234,9 @@ svn_cl__get_human_readable_prop_conflict
         break;
       default:
         action_str = apr_psprintf(pool, _("incoming %s"),
-                                  svn_token__to_word(map_conflict_action_xml,
-                                                     conflict->action));
+                                  svn_token__to_word(
+                                    map_conflict_action_xml,
+                                    conflict->incoming_change));
         break;
     }
   SVN_ERR_ASSERT(reason_str && action_str);
@@ -248,7 +249,7 @@ svn_cl__get_human_readable_prop_conflict
 svn_error_t *
 svn_cl__get_human_readable_tree_conflict_description(
   const char **desc,
-  const svn_wc_conflict_description2_t *conflict,
+  const svn_wc_conflict_description3_t *conflict,
   apr_pool_t *pool)
 {
   const char *action, *reason, *operation;
@@ -256,15 +257,15 @@ svn_cl__get_human_readable_tree_conflict
 
   /* Determine the node kind of the incoming change. */
   incoming_kind = svn_node_unknown;
-  if (conflict->action == svn_wc_conflict_action_edit ||
-      conflict->action == svn_wc_conflict_action_delete)
+  if (conflict->incoming_change == svn_wc_conflict_action_edit ||
+      conflict->incoming_change == svn_wc_conflict_action_delete)
     {
       /* Change is acting on 'src_left' version of the node. */
       if (conflict->src_left_version)
         incoming_kind = conflict->src_left_version->node_kind;
     }
-  else if (conflict->action == svn_wc_conflict_action_add ||
-           conflict->action == svn_wc_conflict_action_replace)
+  else if (conflict->incoming_change == svn_wc_conflict_action_add ||
+           conflict->incoming_change == svn_wc_conflict_action_replace)
     {
       /* Change is acting on 'src_right' version of the node.
        *
@@ -274,9 +275,9 @@ svn_cl__get_human_readable_tree_conflict
         incoming_kind = conflict->src_right_version->node_kind;
     }
 
-  reason = local_reason_str(conflict->node_kind, conflict->reason,
+  reason = local_reason_str(conflict->local_node_kind, conflict->local_change,
                             conflict->operation);
-  action = incoming_action_str(incoming_kind, conflict->action);
+  action = incoming_action_str(incoming_kind, conflict->incoming_change);
   operation = operation_str(conflict->operation);
   SVN_ERR_ASSERT(operation);
 
@@ -291,12 +292,12 @@ svn_cl__get_human_readable_tree_conflict
          It will not be pretty, but is closer to an internal error than
          an ordinary user-facing string. */
       *desc = apr_psprintf(pool, _("local: %s %s incoming: %s %s %s"),
-                           svn_node_kind_to_word(conflict->node_kind),
+                           svn_node_kind_to_word(conflict->local_node_kind),
                            svn_token__to_word(map_conflict_reason_xml,
-                                              conflict->reason),
+                                              conflict->local_change),
                            svn_node_kind_to_word(incoming_kind),
                            svn_token__to_word(map_conflict_action_xml,
-                                              conflict->action),
+                                              conflict->incoming_change),
                            operation);
     }
   return SVN_NO_ERROR;
@@ -339,7 +340,7 @@ add_conflict_version_xml(svn_stringbuf_t
 
 static svn_error_t *
 append_tree_conflict_info_xml(svn_stringbuf_t *str,
-                              const svn_wc_conflict_description2_t *conflict,
+                              const svn_wc_conflict_description3_t *conflict,
                               apr_pool_t *pool)
 {
   apr_hash_t *att_hash = apr_hash_make(pool);
@@ -349,15 +350,15 @@ append_tree_conflict_info_xml(svn_string
                 svn_dirent_basename(conflict->local_abspath, pool));
 
   svn_hash_sets(att_hash, "kind",
-                svn_cl__node_kind_str_xml(conflict->node_kind));
+                svn_cl__node_kind_str_xml(conflict->local_node_kind));
 
   svn_hash_sets(att_hash, "operation",
                 svn_cl__operation_str_xml(conflict->operation, pool));
 
-  tmp = svn_token__to_word(map_conflict_action_xml, conflict->action);
+  tmp = svn_token__to_word(map_conflict_action_xml, conflict->incoming_change);
   svn_hash_sets(att_hash, "action", tmp);
 
-  tmp = svn_token__to_word(map_conflict_reason_xml, conflict->reason);
+  tmp = svn_token__to_word(map_conflict_reason_xml, conflict->local_change);
   svn_hash_sets(att_hash, "reason", tmp);
 
   /* Open the tree-conflict tag. */
@@ -385,7 +386,7 @@ append_tree_conflict_info_xml(svn_string
 
 svn_error_t *
 svn_cl__append_conflict_info_xml(svn_stringbuf_t *str,
-                                 const svn_wc_conflict_description2_t 
*conflict,
+                                 const svn_wc_conflict_description3_t 
*conflict,
                                  apr_pool_t *scratch_pool)
 {
   apr_hash_t *att_hash;
@@ -446,7 +447,7 @@ svn_cl__append_conflict_info_xml(svn_str
       case svn_wc_conflict_kind_property:
         /* "<prop-file> xx </prop-file>" */
         svn_cl__xml_tagged_cdata(&str, scratch_pool, "prop-file",
-                                 conflict->their_abspath);
+                                 conflict->prop_reject_abspath);
         break;
 
       default:

Modified: subversion/trunk/subversion/svn/cl-conflicts.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/cl-conflicts.h?rev=1618670&r1=1618669&r2=1618670&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/cl-conflicts.h (original)
+++ subversion/trunk/subversion/svn/cl-conflicts.h Mon Aug 18 17:27:41 2014
@@ -48,7 +48,7 @@ extern "C" {
 svn_error_t *
 svn_cl__get_human_readable_prop_conflict_description(
   const char **desc,
-  const svn_wc_conflict_description2_t *conflict,
+  const svn_wc_conflict_description3_t *conflict,
   apr_pool_t *pool);
 
 /**
@@ -60,7 +60,7 @@ svn_cl__get_human_readable_prop_conflict
 svn_error_t *
 svn_cl__get_human_readable_tree_conflict_description(
   const char **desc,
-  const svn_wc_conflict_description2_t *conflict,
+  const svn_wc_conflict_description3_t *conflict,
   apr_pool_t *pool);
 
 /**
@@ -70,7 +70,7 @@ svn_cl__get_human_readable_tree_conflict
 svn_error_t *
 svn_cl__append_conflict_info_xml(
   svn_stringbuf_t *str,
-  const svn_wc_conflict_description2_t *conflict,
+  const svn_wc_conflict_description3_t *conflict,
   apr_pool_t *pool);
 
 #ifdef __cplusplus

Modified: subversion/trunk/subversion/svn/cl.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/cl.h?rev=1618670&r1=1618669&r2=1618670&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/cl.h (original)
+++ subversion/trunk/subversion/svn/cl.h Mon Aug 18 17:27:41 2014
@@ -393,7 +393,7 @@ svn_cl__get_conflict_func_interactive_ba
  */
 svn_error_t *
 svn_cl__conflict_func_interactive(svn_wc_conflict_result_t **result,
-                                  const svn_wc_conflict_description2_t *desc,
+                                  const svn_wc_conflict_description3_t *desc,
                                   void *baton,
                                   apr_pool_t *result_pool,
                                   apr_pool_t *scratch_pool);

Modified: subversion/trunk/subversion/svn/conflict-callbacks.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/conflict-callbacks.c?rev=1618670&r1=1618669&r2=1618670&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/info-cmd.c (original)
+++ subversion/trunk/subversion/svn/info-cmd.c Mon Aug 18 17:27:41 2014
@@ -238,9 +238,9 @@ print_info_xml(void *baton,
 
       for (i = 0; i < info->wc_info->conflicts->nelts; i++)
         {
-          const svn_wc_conflict_description2_t *conflict =
-                      APR_ARRAY_IDX(info->wc_info->conflicts, i,
-                                    const svn_wc_conflict_description2_t *);
+          const svn_wc_conflict_description3_t *conflict =
+                      APR_ARRAY_IDX(info->wc_info->conflicts2, i,
+                                    const svn_wc_conflict_description3_t *);
 
           SVN_ERR(svn_cl__append_conflict_info_xml(sb, conflict, pool));
         }
@@ -445,9 +445,9 @@ print_info(void *baton,
 
           for (i = 0; i < info->wc_info->conflicts->nelts; i++)
             {
-              const svn_wc_conflict_description2_t *conflict =
-                    APR_ARRAY_IDX(info->wc_info->conflicts, i,
-                                  const svn_wc_conflict_description2_t *);
+              const svn_wc_conflict_description3_t *conflict =
+                    APR_ARRAY_IDX(info->wc_info->conflicts2, i,
+                                  const svn_wc_conflict_description3_t *);
               const char *desc;
 
               switch (conflict->kind)
@@ -479,8 +479,8 @@ print_info(void *baton,
                     if (! printed_prop_conflict_file)
                       SVN_ERR(svn_cmdline_printf(pool,
                                 _("Conflict Properties File: %s\n"),
-                                svn_dirent_local_style(conflict->their_abspath,
-                                                       pool)));
+                                svn_dirent_local_style(
+                                  conflict->prop_reject_abspath, pool)));
                     printed_prop_conflict_file = TRUE;
                   break;
 
@@ -502,9 +502,9 @@ print_info(void *baton,
           {
             const char *src_left_version;
             const char *src_right_version;
-            const svn_wc_conflict_description2_t *conflict =
-                  APR_ARRAY_IDX(info->wc_info->conflicts, 0,
-                                const svn_wc_conflict_description2_t *);
+            const svn_wc_conflict_description3_t *conflict =
+                  APR_ARRAY_IDX(info->wc_info->conflicts2, 0,
+                                const svn_wc_conflict_description3_t *);
 
             src_left_version =
                         svn_cl__node_description(conflict->src_left_version,

Modified: subversion/trunk/subversion/svn/status.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/status.c?rev=1618670&r1=1618669&r2=1618670&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/status.c (original)
+++ subversion/trunk/subversion/svn/status.c Mon Aug 18 17:27:41 2014
@@ -291,8 +291,7 @@ print_status(const char *target_abspath,
 
           tree_status_code = 'C';
           SVN_ERR(svn_cl__get_human_readable_tree_conflict_description(
-                            &desc, svn_wc__cd3_to_cd2(tree_conflict, pool),
-                            pool));
+                            &desc, tree_conflict, pool));
           tree_desc_line = apr_psprintf(pool, "\n      >   %s", desc);
           (*tree_conflicts)++;
         }


Reply via email to
--- subversion/trunk/subversion/svn/conflict-callbacks.c (original)
+++ subversion/trunk/subversion/svn/conflict-callbacks.c Mon Aug 18 17:27:41 
2014
@@ -127,7 +127,7 @@ svn_cl__accept_from_word(const char *wor
 /* Print on stdout a diff that shows incoming conflicting changes
  * corresponding to the conflict described in DESC. */
 static svn_error_t *
-show_diff(const svn_wc_conflict_description2_t *desc,
+show_diff(const svn_wc_conflict_description3_t *desc,
           const char *path_prefix,
           svn_cancel_func_t cancel_func,
           void *cancel_baton,
@@ -139,7 +139,7 @@ show_diff(const svn_wc_conflict_descript
   svn_stream_t *output;
   svn_diff_file_options_t *options;
 
-  if (desc->merged_file)
+  if (desc->merged_abspath)
     {
       /* For conflicts recorded by the 'merge' operation, show a diff between
        * 'mine' (the working version of the file as it appeared before the
@@ -163,7 +163,7 @@ show_diff(const svn_wc_conflict_descript
           path1 = desc->their_abspath;
           label1 = _("THEIRS");
         }
-      path2 = desc->merged_file;
+      path2 = desc->merged_abspath;
       label2 = _("MERGED");
     }
   else
@@ -203,7 +203,7 @@ show_diff(const svn_wc_conflict_descript
 /* Print on stdout just the conflict hunks of a diff among the 'base', 'their'
  * and 'my' files of DESC. */
 static svn_error_t *
-show_conflicts(const svn_wc_conflict_description2_t *desc,
+show_conflicts(const svn_wc_conflict_description3_t *desc,
                apr_pool_t *pool)
 {
   svn_diff_t *diff;
@@ -242,7 +242,7 @@ show_conflicts(const svn_wc_conflict_des
  */
 static svn_error_t *
 merge_prop_conflict(svn_stream_t *output,
-                    const svn_wc_conflict_description2_t *desc,
+                    const svn_wc_conflict_description3_t *desc,
                     const char *merged_abspath,
                     apr_pool_t *pool)
 {
@@ -298,7 +298,7 @@ merge_prop_conflict(svn_stream_t *output
  * Assume the values are printable UTF-8 text.
  */
 static svn_error_t *
-show_prop_conflict(const svn_wc_conflict_description2_t *desc,
+show_prop_conflict(const svn_wc_conflict_description3_t *desc,
                    const char *merged_abspath,
                    apr_pool_t *pool)
 {
@@ -359,7 +359,7 @@ open_editor(svn_boolean_t *performed_edi
  * environment variables; see svn_cl__edit_file_externally() for details. */
 static svn_error_t *
 edit_prop_conflict(const char **merged_file_path,
-                   const svn_wc_conflict_description2_t *desc,
+                   const svn_wc_conflict_description3_t *desc,
                    svn_cl__interactive_conflict_baton_t *b,
                    apr_pool_t *result_pool,
                    apr_pool_t *scratch_pool)
@@ -678,7 +678,7 @@ prompt_user(const resolver_option_t **op
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_text_conflict(svn_wc_conflict_result_t *result,
-                     const svn_wc_conflict_description2_t *desc,
+                     const svn_wc_conflict_description3_t *desc,
                      svn_cl__interactive_conflict_baton_t *b,
                      apr_pool_t *scratch_pool)
 {
@@ -704,7 +704,7 @@ handle_text_conflict(svn_wc_conflict_res
      markers to the user (this is the typical 3-way merge
      scenario), or if no base is available, we can show a diff
      between mine and theirs. */
-  if ((desc->merged_file && desc->base_abspath)
+  if ((desc->merged_abspath && desc->base_abspath)
       || (!desc->base_abspath && desc->my_abspath && desc->their_abspath))
     diff_allowed = TRUE;
 
@@ -798,7 +798,8 @@ handle_text_conflict(svn_wc_conflict_res
         }
       else if (strcmp(opt->code, "e") == 0 || strcmp(opt->code, ":-E") == 0)
         {
-          SVN_ERR(open_editor(&performed_edit, desc->merged_file, b, 
iterpool));
+          SVN_ERR(open_editor(&performed_edit, desc->merged_abspath, b,
+                              iterpool));
           if (performed_edit)
             knows_something = TRUE;
         }
@@ -810,7 +811,7 @@ handle_text_conflict(svn_wc_conflict_res
           err = svn_cl__merge_file_externally(desc->base_abspath,
                                               desc->their_abspath,
                                               desc->my_abspath,
-                                              desc->merged_file,
+                                              desc->merged_abspath,
                                               desc->local_abspath, b->config,
                                               NULL, iterpool);
           if (err)
@@ -825,7 +826,7 @@ handle_text_conflict(svn_wc_conflict_res
                                              desc->base_abspath,
                                              desc->their_abspath,
                                              desc->my_abspath,
-                                             desc->merged_file,
+                                             desc->merged_abspath,
                                              desc->local_abspath,
                                              b->path_prefix,
                                              b->editor_cmd,
@@ -863,10 +864,10 @@ handle_text_conflict(svn_wc_conflict_res
         {
           /* ### This check should be earlier as it's nasty to offer an option
            *     and then when the user chooses it say 'Invalid option'. */
           /* ### 'merged_file' shouldn't be necessary *before* we launch the
            *     resolver: it should be the *result* of doing so. */
           if (desc->base_abspath && desc->their_abspath &&
-              desc->my_abspath && desc->merged_file)
+              desc->my_abspath && desc->merged_abspath)
             {
               svn_error_t *err;
               char buf[1024];
@@ -875,7 +876,7 @@ handle_text_conflict(svn_wc_conflict_res
               err = svn_cl__merge_file_externally(desc->base_abspath,
                                                   desc->their_abspath,
                                                   desc->my_abspath,
-                                                  desc->merged_file,
+                                                  desc->merged_abspath,
                                                   desc->local_abspath,
                                                   b->config, NULL, iterpool);
               if (err && (err->apr_err == SVN_ERR_CL_NO_EXTERNAL_MERGE_TOOL ||
@@ -906,7 +907,7 @@ handle_text_conflict(svn_wc_conflict_res
                                      desc->base_abspath,
                                      desc->their_abspath,
                                      desc->my_abspath,
-                                     desc->merged_file,
+                                     desc->merged_abspath,
                                      desc->local_abspath,
                                      b->path_prefix,
                                      b->editor_cmd,
@@ -961,7 +962,7 @@ handle_text_conflict(svn_wc_conflict_res
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_prop_conflict(svn_wc_conflict_result_t *result,
-                     const svn_wc_conflict_description2_t *desc,
+                     const svn_wc_conflict_description3_t *desc,
                      svn_cl__interactive_conflict_baton_t *b,
                      apr_pool_t *result_pool,
                      apr_pool_t *scratch_pool)
@@ -971,12 +972,6 @@ handle_prop_conflict(svn_wc_conflict_res
   const char *merged_file_path = NULL;
   svn_boolean_t resolved_allowed = FALSE;
 
-  /* ### Work around a historical bug in the provider: the path to the
-   *     conflict description file was put in the 'theirs' field, and
-   *     'theirs' was put in the 'merged' field. */
-  ((svn_wc_conflict_description2_t *)desc)->their_abspath = desc->merged_file;
-  ((svn_wc_conflict_description2_t *)desc)->merged_file = NULL;
-
   SVN_ERR_ASSERT(desc->kind == svn_wc_conflict_kind_property);
 
   SVN_ERR(svn_cmdline_fprintf(stderr, scratch_pool,
@@ -1064,7 +1059,7 @@ handle_prop_conflict(svn_wc_conflict_res
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_tree_conflict(svn_wc_conflict_result_t *result,
-                     const svn_wc_conflict_description2_t *desc,
+                     const svn_wc_conflict_description3_t *desc,
                      svn_cl__interactive_conflict_baton_t *b,
                      apr_pool_t *scratch_pool)
 {
@@ -1094,15 +1089,15 @@ handle_tree_conflict(svn_wc_conflict_res
       if (desc->operation == svn_wc_operation_update ||
           desc->operation == svn_wc_operation_switch)
         {
-          if (desc->reason == svn_wc_conflict_reason_moved_away)
+          if (desc->local_change == svn_wc_conflict_reason_moved_away)
             {
               tc_opts = tree_conflict_options_update_moved_away;
             }
-          else if (desc->reason == svn_wc_conflict_reason_deleted ||
-                   desc->reason == svn_wc_conflict_reason_replaced)
+          else if (desc->local_change == svn_wc_conflict_reason_deleted ||
+                   desc->local_change == svn_wc_conflict_reason_replaced)
             {
-              if (desc->action == svn_wc_conflict_action_edit &&
-                  desc->node_kind == svn_node_dir)
+              if (desc->incoming_change == svn_wc_conflict_action_edit &&
+                  desc->local_node_kind == svn_node_dir)
                 tc_opts = tree_conflict_options_update_edit_deleted_dir;
             }
         }
@@ -1135,7 +1130,7 @@ handle_tree_conflict(svn_wc_conflict_res
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_obstructed_add(svn_wc_conflict_result_t *result,
-                      const svn_wc_conflict_description2_t *desc,
+                      const svn_wc_conflict_description3_t *desc,
                       svn_cl__interactive_conflict_baton_t *b,
                       apr_pool_t *scratch_pool)
 {
@@ -1182,7 +1177,7 @@ handle_obstructed_add(svn_wc_conflict_re
 /* The body of svn_cl__conflict_func_interactive(). */
 static svn_error_t *
 conflict_func_interactive(svn_wc_conflict_result_t **result,
-                          const svn_wc_conflict_description2_t *desc,
+                          const svn_wc_conflict_description3_t *desc,
                           void *baton,
                           apr_pool_t *result_pool,
                           apr_pool_t *scratch_pool)
@@ -1209,7 +1204,7 @@ conflict_func_interactive(svn_wc_conflic
     case svn_cl__accept_working:
       /* If the caller didn't merge the property values, then I guess
        * 'choose working' means 'choose mine'... */
-      if (! desc->merged_file)
+      if (! desc->merged_abspath)
         (*result)->merged_file = desc->my_abspath;
       (*result)->choice = svn_wc_conflict_choose_merged;
       return SVN_NO_ERROR;
@@ -1226,7 +1221,7 @@ conflict_func_interactive(svn_wc_conflic
       (*result)->choice = svn_wc_conflict_choose_theirs_full;
       return SVN_NO_ERROR;
     case svn_cl__accept_edit:
-      if (desc->merged_file)
+      if (desc->merged_abspath)
         {
           if (b->external_failed)
             {
@@ -1234,7 +1229,7 @@ conflict_func_interactive(svn_wc_conflic
               return SVN_NO_ERROR;
             }
 
-          err = svn_cmdline__edit_file_externally(desc->merged_file,
+          err = svn_cmdline__edit_file_externally(desc->merged_abspath,
                                                   b->editor_cmd, b->config,
                                                   scratch_pool);
           if (err && (err->apr_err == SVN_ERR_CL_NO_EXTERNAL_EDITOR ||
@@ -1258,7 +1253,7 @@ conflict_func_interactive(svn_wc_conflic
       break;
     case svn_cl__accept_launch:
       if (desc->base_abspath && desc->their_abspath
-          && desc->my_abspath && desc->merged_file)
+          && desc->my_abspath && desc->merged_abspath)
         {
           svn_boolean_t remains_in_conflict;
 
@@ -1271,7 +1266,7 @@ conflict_func_interactive(svn_wc_conflic
           err = svn_cl__merge_file_externally(desc->base_abspath,
                                               desc->their_abspath,
                                               desc->my_abspath,
-                                              desc->merged_file,
+                                              desc->merged_abspath,
                                               desc->local_abspath,
                                               b->config,
                                               &remains_in_conflict,
@@ -1317,8 +1312,8 @@ conflict_func_interactive(svn_wc_conflic
      Conflicting edits on a property.
   */
   if (((desc->kind == svn_wc_conflict_kind_text)
-       && (desc->action == svn_wc_conflict_action_edit)
-       && (desc->reason == svn_wc_conflict_reason_edited)))
+       && (desc->incoming_change == svn_wc_conflict_action_edit)
+       && (desc->local_change == svn_wc_conflict_reason_edited)))
     SVN_ERR(handle_text_conflict(*result, desc, b, scratch_pool));
   else if (desc->kind == svn_wc_conflict_kind_property)
     SVN_ERR(handle_prop_conflict(*result, desc, b, result_pool, scratch_pool));
@@ -1341,8 +1336,8 @@ conflict_func_interactive(svn_wc_conflic
       postpone               [              bail out                 ]
 
    */
-  else if ((desc->action == svn_wc_conflict_action_add)
-           && (desc->reason == svn_wc_conflict_reason_obstructed))
+  else if ((desc->incoming_change == svn_wc_conflict_action_add)
+           && (desc->local_change == svn_wc_conflict_reason_obstructed))
     SVN_ERR(handle_obstructed_add(*result, desc, b, scratch_pool));
 
   else if (desc->kind == svn_wc_conflict_kind_tree)
@@ -1358,7 +1353,7 @@ conflict_func_interactive(svn_wc_conflic
 
 svn_error_t *
 svn_cl__conflict_func_interactive(svn_wc_conflict_result_t **result,
-                                  const svn_wc_conflict_description2_t *desc,
+                                  const svn_wc_conflict_description3_t *desc,
                                   void *baton,
                                   apr_pool_t *result_pool,
                                   apr_pool_t *scratch_pool)
@@ -863,10 +864,10 @@ handle_text_conflict(svn_wc_conflict_res
           /* ### This check should be earlier as it's nasty to offer an option
            *     and then when the user chooses it say 'Invalid option'. */
-          /* ### 'merged_file' shouldn't be necessary *before* we launch the
+          /* ### 'merged_abspath' shouldn't be necessary *before* we launch the
            *     resolver: it should be the *result* of doing so. */
           if (desc->base_abspath && desc->their_abspath &&

Modified: subversion/trunk/subversion/svn/info-cmd.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/info-cmd.c?rev=1618670&r1=1618669&r2=1618670&view=diff
==============================================================================